@@ -20,18 +20,20 @@ __is_libpsp__ = True
 try:
     # Load all `libbinding` depending modules in one go, otherwise nothing
     # dependent on `libbinding` is exposed.
-    from .table import *  # noqa: F401, F403
-    from .manager import *  # noqa: F401, F403
-    from .tornado_handler import *  # noqa: F401, F403
-    from .viewer import *  # noqa: F401, F403
+    from .table import *
+    from .manager import *
+    from .viewer import *
     from .table.libbinding import (
         init_expression_parser,
     )
 
     def set_threadpool_size(nthreads):
         """Sets the size of the global Perspective thread pool, up to the
-        total number of available cores, which can be set explicity by
-        setting `nthreads` to `None`.
+        total number of available cores.  Passing an explicit
+        `None` sets this limit to the detected hardware concurrency from the
+        environment, which is also the default if this method is never called.
+        `set_threadpool_size()` must be called before any other
+        `perspective-python` API calls, and cannot be changed after such a call.
         """
         os.environ["OMP_THREAD_LIMIT"] = "0" if nthreads is None else str(nthreads)
 
